#ifndef NT2_INCLUDE_FUNCTIONS_COMPLEMENT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMPLEMENT_HPP_INCLUDED

#include <nt2/operator/include/functions/complement.hpp>

#endif
